@@ -1,3 +1,4 @@
+import re
 from typing import Any, TypeVar, get_args, get_origin
 
 from .typedef import DisassembledType
@@ -44,6 +45,24 @@ def implements(cls: type, name: str):
         return False
 
     return next(
-        (False for base_cls in cls.mro()[1:] if getattr(base_cls, name, None) is attr),
+        (
+            False
+            for base_cls in cls.mro()[1:]
+            if getattr(base_cls, name, None) is attr
+        ),
         True,
     )
+
+
+_to_camel_regex = re.compile("_([a-zA-Z])")
+
+
+def to_camel(string: str) -> str:
+    return _to_camel_regex.sub(
+        lambda match: match[1].upper(), string.strip("_")
+    )
+
+
+def to_upper_camel(string: str) -> str:
+    result = to_camel(string)
+    return result[:1].upper() + result[1:]
